@@ -11,7 +11,7 @@ our $VERSION = '0.01';
 __PACKAGE__->config( name => 'TestApp' ,
 "Controller::Root" => {}
 );
-__PACKAGE__->setup(qw//);
+__PACKAGE__->setup(qw/Static::Simple/);
 
 
 1;
